#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 persistent-postgresql
version:              2.13.5.2
visibility:           public
id:                   persistent-postgresql-2.13.5.2-CDK8AHpNtnxDwYa2Hupjf9
key:                  persistent-postgresql-2.13.5.2-CDK8AHpNtnxDwYa2Hupjf9
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Felipe Lessa, Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:             Backend for the persistent library using postgresql.
description:          Based on the postgresql-simple package
category:             Database, Yesod
abi:                  405d594ab67624e8d10ccfcefe639c3f
exposed:              True
exposed-modules:
    Database.Persist.Postgresql Database.Persist.Postgresql.Internal
    Database.Persist.Postgresql.JSON

import-dirs:
    /usr/lib/ghc-9.6.6/site-local/persistent-postgresql-2.13.5.2

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/persistent-postgresql-2.13.5.2

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/persistent-postgresql-2.13.5.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-postgresql
hs-libraries:         HSpersistent-postgresql-2.13.5.2-CDK8AHpNtnxDwYa2Hupjf9
depends:
    aeson-2.2.2.0-Bvq1RZLTB982HJyF7e96XU
    attoparsec-0.14.4-9CcJCC4ORykBmnSiMZ6uwP base-4.18.2.1
    blaze-builder-0.4.4.1-1osLiMNDaK0LJVibZzd2na bytestring-0.11.5.3
    conduit-1.3.6.1-534uwm1BQ035a3x29nwuhR containers-0.6.7
    monad-logger-0.3.42-HNH8CK1RnpJ4FKeE6FjTtm mtl-2.3.1
    persistent-2.14.5.2-E7tj1bN59VcDNU1kXNXcaK
    postgresql-libpq-0.9.5.0-6Abcvnlrbx38D8lE6uFyjU
    postgresql-simple-0.6.5.1-DmuchojAEaLLwfA2IWuGIr
    resource-pool-0.2.3.2-DMGI0pYU0BGFl9V5LmPWsy
    resourcet-1.2.6-5o8OKNGoLEyGu1zh0QIf5q
    string-conversions-0.4.0.1-8dXJHMHsAt1EbIWBeN8y9V text-2.0.2
    time-1.12.2 transformers-0.6.1.0
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    vault-0.3.1.6-9LEDSQf01dO8jjPC40E1mt

haddock-interfaces:
    /usr/share/doc/haskell-persistent-postgresql/html/persistent-postgresql.haddock

haddock-html:         /usr/share/doc/haskell-persistent-postgresql/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

